#!/usr/bin/env python
# coding: utf-8

# In[ ]:

"""Welcome to phdutils.bcdi.gui."""

__all__ = ["gui", "gui_iterable"]
